@@ -329,11 +329,11 @@ function(y, mc=TRUE, ar=NULL, ewma=NULL, mxreg=NULL,
       ##print info:
       if(is.null(parallel.options)){
         if(print.searchinfo){
-          message("\n", appendLF=FALSE)
+          message("\\n", appendLF=FALSE)
           message(names(ISmatrices)[i],
             " block ", j, " of ", length(ISblocks[[i]]), ":",
             appendLF=TRUE)
-          #message("\n", appendLF=FALSE)
+          #message("\\n", appendLF=FALSE)
         }
       }
 
@@ -380,14 +380,14 @@ function(y, mc=TRUE, ar=NULL, ewma=NULL, mxreg=NULL,
 
       ##print info:
       if(print.searchinfo){
-        message("\n", appendLF=FALSE)
+        message("\\n", appendLF=FALSE)
         message("Preparing parallel computing...",
           appendLF=TRUE)
         message(names(ISmatrices)[i],
           " blocks to search in parallel: ", length(ISblocks[[i]]),
           appendLF=TRUE)
         message("Searching...", appendLF=TRUE)
-        #message("\n", appendLF=FALSE)
+        #message("\\n", appendLF=FALSE)
       }
 
       blocksClust <- makeCluster(clusterSpec, outfile="") #make cluster
@@ -410,7 +410,7 @@ function(y, mc=TRUE, ar=NULL, ewma=NULL, mxreg=NULL,
 
     ##print info:
     if(print.searchinfo){
-      message("\n", appendLF=FALSE)
+      message("\\n", appendLF=FALSE)
       message("GETS of union of retained ",
         names(ISmatrices)[i], " variables... ",
         appendLF=TRUE)
@@ -473,10 +473,10 @@ function(y, mc=TRUE, ar=NULL, ewma=NULL, mxreg=NULL,
   
   ##some info:
   if(print.searchinfo){
-    message("\n", appendLF=FALSE)
+    message("\\n", appendLF=FALSE)
     message("GETS of union of ALL retained variables...",
       appendLF=TRUE)
-    #message("\n", appendLF=FALSE)
+    #message("\\n", appendLF=FALSE)
   }
 
   ##if final models estimated:
@@ -529,11 +529,14 @@ function(y, mc=TRUE, ar=NULL, ewma=NULL, mxreg=NULL,
     max.regs=max.regs, print.searchinfo=print.searchinfo,
     alarm=FALSE)
   ##messages from final gets:
-  if( print.searchinfo && !is.null(getsis$messages)){ message(getsis$messages) }
+  if( print.searchinfo && !is.null(getsis$messages)){
+    message(getsis$messages)
+  }
        
   ##estimate final model:
   y <- zoo(y, order.by=y.index)
   if(is.null(getsis$specific.spec)){
+    mXisNames <- NULL
     mXis <- NULL
   }else{
     mXisNames <- colnames(mXis)[getsis$specific.spec]
@@ -553,13 +556,15 @@ function(y, mc=TRUE, ar=NULL, ewma=NULL, mxreg=NULL,
   mod$call <- NULL
    
   ##complete the returned object (result):
-  ISnames <- setdiff(getsis$aux$mXnames, mXnames) #names of retained impulses
+  ISnames <- setdiff(mXisNames, mXnames) #names of retained impulses
+#OLD:
+#  ISnames <- setdiff(getsis$aux$mXnames, mXnames) #names of retained impulses
   if(length(ISnames)==0){ ISnames <- NULL }
   colnames(mod$aux$mX) <- mod$aux$mXnames #needed for predict.isat?
   getsis$gets.type <- "isat"
   getsis$call <- isat.call
-  getsis <- c(list(ISfinalmodels=ISfinalmodels,
-    ISnames=ISnames), getsis, mod)
+  getsis <-
+    c(list(ISfinalmodels=ISfinalmodels, ISnames=ISnames), getsis, mod)
   getsis$aux$t.pval <- t.pval #needed for biascorr
   class(getsis) <- "isat"
   if(alarm){ alarm() }
