@@ -7,13 +7,13 @@ function(x, signif.stars=FALSE, ...)
   varianceResults <- ifelse("variance.results" %in% xNames, TRUE, FALSE)
 
   ##header - first part:
-  cat("\n")
-  cat("Date:", x$date, "\n")
+  cat("\\n")
+  cat("Date:", x$date, "\\n")
   if(meanResults || varianceResults){
     estType <- ifelse(is.null(x$aux$user.estimator),
       "Ordinary Least Squares (OLS)", "User defined")
-    cat("Dependent var.:", x$aux$y.name, "\n")
-    cat("Method:", estType, "\n")
+    cat("Dependent var.:", x$aux$y.name, "\\n")
+    cat("Method:", estType, "\\n")
   }
 
   ##header - if mean results:
@@ -21,18 +21,18 @@ function(x, signif.stars=FALSE, ...)
     if(is.null(x$aux$user.estimator)){
       cat("Variance-Covariance:", switch(x$aux$vcov.type,
         ordinary = "Ordinary", white = "White (1980)",
-        "newey-west" = "Newey and West (1987)"), "\n")
+        "newey-west" = "Newey and West (1987)"), "\\n")
     }
     if("residuals" %in% xNames){
       cat("No. of observations (mean eq.):",
-        length(na.trim(x$residuals)), "\n")
+        length(na.trim(x$residuals)), "\\n")
     }
   }
 
   ##header - if variance results:
   if( varianceResults && "resids.std" %in% xNames ){
     cat("No. of observations (variance eq.):",
-      length(na.trim(x$std.residuals)), "\n")
+      length(na.trim(x$std.residuals)), "\\n")
   }
 
   ##header - sample info:
@@ -52,29 +52,29 @@ function(x, signif.stars=FALSE, ...)
       startAsChar <- as.character(indexTrimmed[1])
       endAsChar <- as.character(indexTrimmed[length(indexTrimmed)])
     }
-    cat("Sample:", startAsChar, "to", endAsChar, "\n")
+    cat("Sample:", startAsChar, "to", endAsChar, "\\n")
   } #end if( "residuals" %in% xNames )
 
   ##print mean results:
   if(meanResults){
-    cat("\n")
-    cat("Mean equation:\n")
-    cat("\n")
+    cat("\\n")
+    cat("Mean equation:\\n")
+    cat("\\n")
     printCoefmat(x$mean.results, signif.stars=signif.stars)
   }
 
   ##print variance results:
   if(varianceResults){
-    cat("\n")
-    cat("Log-variance equation:\n")
-    cat("\n")
+    cat("\\n")
+    cat("Log-variance equation:\\n")
+    cat("\\n")
     printCoefmat(x$variance.results, signif.stars=signif.stars)
   }
 
   ##print if no results:
   if( !meanResults && !varianceResults ){
-    cat("\n")
-    cat("   No estimation results\n")
+    cat("\\n")
+    cat("   No estimation results\\n")
   }
 
   ##goodness-of-fit:
@@ -91,9 +91,9 @@ function(x, signif.stars=FALSE, ...)
 
   ##print diagnostics and fit:
   if( !is.null(x$diagnostics) ) {
-    cat("\n")
-    cat("Diagnostics and fit:\n")
-    cat("\n")
+    cat("\\n")
+    cat("Diagnostics and fit:\\n")
+    cat("\\n")
     printCoefmat(x$diagnostics, dig.tst=0, tst.ind=2,
       signif.stars=FALSE)
     if( !is.null(x$gof) ){printCoefmat(x$gof, digits=6, signif.stars=FALSE) }
